# Generated by Django 4.1.9 on 2023-05-10 11:39

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("onetimelink", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="download",
            name="down_file",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="downloads",
                to="onetimelink.uploadfile",
            ),
        ),
        migrations.AlterField(
            model_name="uploadfile",
            name="file",
            field=models.FileField(
                blank=True,
                help_text="Select the file to upload",
                max_length=255,
                null=True,
                upload_to="",
                verbose_name="file",
            ),
        ),
    ]
