{% load static i18n %}

{% block page_css %}

<link href="{% static 'css/not_avallible.css' %}" rel="stylesheet">

{% endblock %}

{% block title %}

    {% trans "Not Available" %}

{% endblock %}

{% block content %}

{% endblock %}